@@ -1,6 +1,8 @@
-from PySimultan import TemplateParser
+from PySimultan import TemplateParser, DataModel, Template, yaml
 from .geometry.extended_geometry import ExtendedVertex, ExtendedEdge, ExtendedEdgeLoop, ExtendedFace, ExtendedVolume
 import colorlog
+from .foi import ReferenceList
+from .weather import Weather
 
 TemplateParser.geo_bases['vertex'] = ExtendedVertex
 TemplateParser.geo_bases['edge'] = ExtendedEdge
@@ -8,6 +10,9 @@ TemplateParser.geo_bases['edge_loop'] = ExtendedEdgeLoop
 TemplateParser.geo_bases['face'] = ExtendedFace
 TemplateParser.geo_bases['volume'] = ExtendedVolume
 
+TemplateParser.bases['ReferenceList'] = ReferenceList
+TemplateParser.bases['Weather'] = Weather
+
 handler = colorlog.StreamHandler()
 formatter = colorlog.ColoredFormatter(
     "%(log_color)s%(levelname)-8s%(reset)s %(blue)s%(message)s",
@@ -24,7 +29,6 @@ formatter = colorlog.ColoredFormatter(
     style='%'
 )
 
-
 handler.setFormatter(formatter)
 
 logger = colorlog.getLogger('PySimultanRadiation')
